import { pathToFileURL } from 'node:url';
/** @internal */
export const loadTSConfig = async (configPath) => {
    let importx = undefined;
    let jiti = undefined;
    try {
        importx = await import('importx');
    }
    catch {
        try {
            jiti = await import('jiti');
        }
        catch {
            throw new Error("'jiti' or 'importx' is required for loading TypeScript configuration files. Make sure to install one of them.");
        }
    }
    if (importx) {
        const config = await importx.import(configPath, import.meta.url);
        return config.default;
    }
    if (jiti) {
        return jiti.default(import.meta.url, {
            interopDefault: true,
            esmResolve: true,
        })(configPath);
    }
    throw new Error("'jiti' or 'importx' is required for loading TypeScript configuration files. Make sure to install one of them.");
};
export const loadConfig = async (configPath) => {
    if (configPath.endsWith('.ts')) {
        return loadTSConfig(configPath);
    }
    const { default: config } = await import(pathToFileURL(configPath).href);
    return config;
};
