import { LintMessage } from './types.js';
export type WorkerMessage = {
    type: 'START';
} | {
    type: 'READ';
} | {
    type: 'CLONE';
} | {
    type: 'PULL';
} | {
    type: 'ON_RESULT';
    payload: {
        messages: LintMessage[];
    };
} | {
    type: 'LINT_START';
    payload: number;
} | {
    type: 'LINT_END';
} | {
    type: 'FILE_LINT_END';
    payload: {
        fileIndex: number;
    };
} | {
    type: 'FILE_LINT_SLOW';
    payload: {
        path: string;
        lintTime: number;
    };
} | {
    type: 'LINTER_CRASH';
    payload: string;
} | {
    type: 'WORKER_ERROR';
    payload?: string;
} | {
    type: 'READ_FAILURE';
} | {
    type: 'CLONE_FAILURE';
} | {
    type: 'PULL_FAILURE';
} | {
    type: 'DEBUG';
    payload: any;
};
/**
 * Create error message for LintMessage results
 */
export declare function createErrorMessage(error: Omit<LintMessage, 'column' | 'line' | 'severity'> & {
    line?: number;
}): LintMessage;
/**
 * Task for worker threads:
 * - Expects workerData to contain array of repositories as strings
 * - Read files from repository-client
 * - Run ESLint on file contents
 * - Parse messages and pass lint results back to the main thread
 * - Keep progress-logger up-to-date of status via onMessage
 */
export default function workerTask(): Promise<void>;
//# sourceMappingURL=worker-task.d.ts.map